@@ -16,12 +16,7 @@ fn genesis_builtins(bpf_jit: bool) -> Vec<Builtin> {
     // !x86_64: https://github.com/qmonnet/rbpf/issues/48
     // Windows: https://github.com/solana-labs/rbpf/issues/217
     #[cfg(any(not(target_arch = "x86_64"), target_family = "windows"))]
-    let bpf_jit = {
-        if bpf_jit {
-            info!("BPF JIT is not supported on this target");
-        }
-        false
-    };
+    let bpf_jit = false;
 
     vec![
         to_builtin!(solana_bpf_loader_deprecated_program!()),
